.. include:: ../README.rst
    :end-before: when included in index.rst

Source repository
-----------------------------------------------------------------------

${git_url}/${repository_name}

Documentation
-----------------------------------------------------------------------

.. grid:: 2

    .. grid-item-card:: :material-regular:`person;4em`
        :link: user/index
        :link-type: doc

        The User Guide contains documentation on how to install and use the software.

.. toctree::
    :hidden:

    user/index
